@@ -38,7 +38,7 @@ class CountedIterator {
    */
   CountedIterator(const CountedIterator &other) {
     data_ = other.data_;
-    data_->count++;
+    data_->count_++;
   }
 
   ~CountedIterator() { dispose(); }
@@ -75,7 +75,7 @@ class CountedIterator {
     if (this != &other) {
       dispose();
       data_ = other.data_;
-      data_->count++;
+      data_->count_++;
     }
     return *this;
   }
@@ -101,8 +101,8 @@ class CountedIterator {
  private:
   void dispose() {
     if (data_ != NULL) {
-      data_->count--;
-      if (data_->count == 0) FunctionClass::dispose(data_);
+      data_->count_--;
+      if (data_->count_ == 0) FunctionClass::dispose(data_);
     }
   }
   typename FunctionClass::ReferencePointer data_;
