@@ -14,8 +14,12 @@ class Environment;
 struct ErrorInformation;
 
 struct EnvironmentRefPointer {
-  std::size_t count;
-  std::map<std::string, std::string>::const_iterator it;
+  std::size_t count_;
+  std::map<std::string, std::string>::const_iterator it_;
+  EnvironmentRefPointer(
+      size_t count,
+      const std::map<std::string, std::string>::const_iterator& it)
+      : count_(count), it_(it) {}
 };
 
 extern "C" {
@@ -23,7 +27,8 @@ AMPLAPI Environment* AMPL_Environment_Create(ErrorInformation* errorInfo);
 AMPLAPI Environment* AMPL_Environment_Copy(const Environment* other,
                                            ErrorInformation* errorInfo);
 AMPLAPI Environment* AMPL_Environment_Create_WithBin(
-    const char* binaryDirectory, ErrorInformation* errorInfo);
+    const char* binaryDirectory, const char* binaryName,
+    ErrorInformation* errorInfo);
 AMPLAPI void AMPL_Environment_Destroy(Environment* env);
 AMPLAPI void AMPL_Environment_addEnvironmentVariable(
     Environment* env, const char* name, const char* value,
@@ -31,8 +36,13 @@ AMPLAPI void AMPL_Environment_addEnvironmentVariable(
 AMPLAPI void AMPL_Environment_setBinaryDirectory(Environment* env,
                                                  const char* binaryDirectory,
                                                  ErrorInformation* errorInfo);
+AMPLAPI void AMPL_Environment_setBinaryName(Environment* env,
+                                            const char* binaryName,
+                                            ErrorInformation* errorInfo);
 AMPLAPI const char* AMPL_Environment_getBinaryDirectory(
     Environment* env, ErrorInformation* errorInfo);
+AMPLAPI const char* AMPL_Environment_getBinaryName(Environment* env,
+                                                   ErrorInformation* errorInfo);
 AMPLAPI std::size_t AMPL_Environment_size(Environment* env,
                                           ErrorInformation* errorInfo);
 AMPLAPI const char* AMPL_Environment_toString(Environment* env,
